###################################################
### chunk number 1:  eval=FALSE
###################################################
## 
## install.packages("svUnit",repos="http://R-Forge.R-project.org")
## 


###################################################
### chunk number 2: 
###################################################

options(useFancyQuotes = FALSE)



###################################################
### chunk number 3: 
###################################################

library(svUnit)

Square <- function(x) return(x^2)

test(Square) <- function() {

    checkEquals(9, Square(3))

    checkEquals(10, Square(3))  # This intentionally fails

    checkEquals(9, SSSquare(3)) # This intentionally raises error

    checkEquals(c(1, 4, 9), Square(1:3))

    checkException(Square("xx"))

}

clearLog()

(runTest(Square))



###################################################
### chunk number 4: 
###################################################

library(svUnit)

# Create two R functions that include their test own cases

Square <- function(x) return(x^2)

test(Square) <- function() {

    checkEquals(9, Square(3))

    checkEquals(c(1, 4, 9), Square(1:3))

    checkException(Square("xx"))

}



Cube <- function(x) return(x^3)

test(Cube) <- function() {

    checkEquals(27, Cube(3))

    checkEquals(c(1, 8, 28), Cube(1:3))

    checkException(Cube("xx"))

}



# Add a separate test case object (not attached to a particular object)

test_Integrate <- svTest(function() {

    checkTrue(1 < 2, "check1")

    v <- 1:3  # The reference

    w <- 1:3  # The value to compare to the reference

    checkEquals(v, w)

})  



###################################################
### chunk number 5: 
###################################################

clearLog()

runTest(Square)

runTest(test_Integrate)

Log()



###################################################
### chunk number 6: 
###################################################

runTest(Cube)

Log()



###################################################
### chunk number 7: 
###################################################

clearLog()

checkTrue(1 == log(exp(1)))

checkException(log("a"))

checkTrue(1 == 2)

Log()



###################################################
### chunk number 8: 
###################################################

# Clear test exclusion list (to run test suites defined in svUnit)

options(svUnit.excludeList = NULL)

# Clear the log

clearLog()

# Run all currently defined tests, including test suites in svUnit

runTest(svSuiteList(), name = "AllTests")

# Get some statistics

stats(Log())[, 1:3]

# A slightly different presentation than print

summary(Log())

# Metadata collected on the machine where tests are run

metadata(Log())

# List content of the log

ls(Log())



###################################################
### chunk number 9: 
###################################################

myTest <- Log()$testCube

class(myTest)

myTest

summary(myTest)

stats(myTest)



###################################################
### chunk number 10: 
###################################################

ls(Log())

rm(test_R, envir = Log())

ls(Log())



###################################################
### chunk number 11: 
###################################################

test_function <- function() {

    checkTrue(1 < 2, "check1")

    v <- 1:3  # The reference

    w <- 1:3  # The value to compare to the reference

    checkEquals(v, w)

}

test_function <- as.svTest(test_function)

is.svTest(test_function)



###################################################
### chunk number 12: 
###################################################

clearLog()

runTest(test_function)

Log()



###################################################
### chunk number 13: 
###################################################

# A very simple function

Square <- function(x) return(x^2)



# A test case to associate with the Square() function

test(Square) <- function() {

    checkEquals(9, Square(3))

    checkEquals(c(1, 4, 9), Square(1:3))

    checkException(Square("xx"))

}

is.test(Square) # Does this object contain tests?



###################################################
### chunk number 14: 
###################################################

test(Square)



###################################################
### chunk number 15: 
###################################################

runTest(Square)

Log()  # Remember we didn't clear log, so we add to the report here



###################################################
### chunk number 16: 
###################################################

# Create a test unit on disk and view it

unit <- makeUnit(Square)

file.show(unit, delete.file = TRUE)



###################################################
### chunk number 17: 
###################################################

example(unitTests.svUnit)



###################################################
### chunk number 18: 
###################################################

# Reset default exclusion list

options(svUnit.excludeList = c("package:sv", "package:Runit"))

svSuiteList() # List all currently available tests



###################################################
### chunk number 19: 
###################################################

# Clear exclusion list

options(svUnit.excludeList = NULL)

svSuiteList()



###################################################
### chunk number 20: 
###################################################

(mySuite <- svSuiteList())



###################################################
### chunk number 21: 
###################################################

myUnit <- makeUnit(mySuite, name = "ExampleTests")

file.show(myUnit, delete.file = TRUE)



###################################################
### chunk number 22: 
###################################################

clearLog()

runTest(mySuite)

summary(Log())



